import { defineStore } from "pinia";
import { getToken, removeToken, setToken } from "@/utils/auth";
import { getInfo, login, logout } from "@/api/login";

export const useUserStore = defineStore("user", {
  state: () => {
    return {
      token: getToken(),
      name: "",
      avatar: "",
      roles: [],
      permissions: [],
    };
  },
  actions: {
    // 登录
    login(userInfo: any) {
      const username = userInfo.username.trim();
      const password = userInfo.password;
      const code = userInfo.code;
      const uuid = userInfo.uuid;
      return new Promise((resolve, reject) => {
        login(username, password, code, uuid)
          .then((res: any) => {
            setToken(res.data.token);
            this.token = res.data.token;
            resolve(null);
          })
          .catch((error: any) => {
            reject(error);
          });
      });
    },
    // 退出系统
    logOut() {
      return new Promise<void>((resolve, reject) => {
        logout()
          .then(() => {
            this.token = "";
            removeToken();
            resolve();
          })
          .catch((error: any) => {
            reject(error);
          });
      });
    }, // 获取用户信息
    getInfo() {
      return new Promise((resolve, reject) => {
        getInfo()
          .then((res: any) => {
            const user = res.data.user;
            // const avatar = (user.avatar == "" || user.avatar == null) ? defAva : import.meta.env.VITE_APP_BASE_API + user.avatar;

            if (res.data.roles && res.data.roles.length > 0) {
              // 验证返回的roles是否是一个非空数组
              this.roles = res.data.roles;
              this.permissions = res.data.permissions;
            } else {
              // @ts-ignore
              this.roles = ["ROLE_DEFAULT"];
            }
            this.name = user.userName;
            // this.avatar = avatar;
            resolve(res.data);
          })
          .catch((error) => {
            reject(error);
          });
      });
    },
  },
});
